<?php

namespace CreoCode\ContaoColumns\Listener;
use Contao\DataContainer;
use Contao\Database;

# Log
use Psr\Log\LogLevel;
use Contao\CoreBundle\Monolog\ContaoContext;

/**
 * ContentDataContainer helper class.
 */
class ComponentListener
{
    /*
	 * Get all sets from the configuration array
	 */
	public function getSets()
	{
		$arrSets = array();
		foreach($GLOBALS['TL_SUBCL'] as $k=>$v) {
			$arrSets[$k] = $v['label'];
		}
		return $arrSets;
	}


	public function pageCheck($intId=0)
	{
        $this->Database = Database::getInstance();
		if($intId==0) return '';


		$objArticle = $this->Database->prepare("SELECT id FROM tl_article WHERE pid=?")
									 ->execute($intId);
		if($objArticle->numRows > 0)
		{
			while($objArticle->next())
			{
				$this->copyCheck($objArticle->id);
			}
		}
	}

	public function articleCheck($intId=0)
	{
		if($intId==0) return '';
		$this->copyCheck($intId);

	}

	/**
     *
     * HOOK: $GLOBALS['TL_HOOKS']['clipboardCopyAll']
     *
     * @param array $arrIds
     */
    public function clipboardCopyAll($arrIds)
    {
        $this->Database = Database::getInstance();
        $arrIds = array_keys(array_flip($arrIds));

		$objDb = $this->Database->execute("SELECT DISTINCT pid FROM tl_content WHERE id IN (".implode(',',$arrIds).")");

		if($objDb->numRows > 0)
		{
			while($objDb->next())
			{
				$this->copyCheck($objDb->pid);
			}
		}

    }


	/**
     * Copy a colset
     *
     * @param integer $pid
     */
	public function copyCheck($pid)
	{
        $this->Database = Database::getInstance();
		$objcolsStarts = $this->Database->prepare("SELECT id,column_childs FROM tl_content WHERE pid=? AND type=? ORDER BY sorting")
												->execute($pid,'colsStart');

		if($objcolsStarts->numRows > 0)
		{
			$parent = 0;
			$childs = array();
			$parents = array();
			while($objcolsStarts->next())
			{
				$column_name = 'colset.' . $objcolsStarts->id;
				$column_parent = $objcolsStarts->id;
				$parent = $objcolsStarts->id;
				$oldChilds = unserialize($objcolsStarts->column_childs);
				$oldChildParent = $this->Database->prepare("SELECT column_parent FROM tl_content WHERE id=?")
											    ->limit(1)
												->execute($oldChilds[0]);

				$newChilds = $this->Database->prepare("SELECT id,type FROM tl_content WHERE pid=? AND column_parent=? AND type != 'colsStart'")
												->execute($pid,$oldChildParent->column_parent);
				$i=1;
				while($newChilds->next())
				{
					$childs[$parent]['column_childs'][] = $newChilds->id;
					$parents[$newChilds->id]['column_parent'] = $parent;
					$parents[$newChilds->id]['column_name'] = $column_name . ($newChilds->type=="colsPart" ? '-Part-' . $i : '-End');
					$parents[$newChilds->id]['column_sortid'] = $i;
					$i++;
				}
				$childs[$parent]['column_parent'] = $column_parent;
				$childs[$parent]['column_name'] = $column_name;
				sort($childs[$parent]['column_childs']);

			}

			foreach($childs as $key=>$child)
			{
				$this->Database->prepare("UPDATE tl_content %s WHERE id=?")
											->set(array('column_parent'=>$child['column_parent'],'column_childs'=>$child['column_childs'],'column_name'=>$child['column_name']))
											->execute($key);
			}

			foreach($parents as $key=>$parent)
			{
				$this->Database->prepare("UPDATE tl_content %s WHERE id=?")
											->set(array('column_parent'=>$parent['column_parent'],'column_name'=>$parent['column_name'],'column_sortid'=>$parent['column_sortid']))
											->execute($key);
			}

		}

	}

	public function formCheck($intId,DataContainer $dc)
	{
        $this->Database = Database::getInstance();
		if($intId==0) return '';

		$objElements = $this->Database->prepare("SELECT id,column_parent FROM tl_form_field WHERE pid=? AND type=?")->execute($intId,'formColsStart');

		if($objElements->numRows == 0) return '';

		while($objElements->next())
		{
			$strName = 'colset.' . $objElements->id;
			$this->Database->prepare("UPDATE tl_form_field %s WHERE pid=? AND column_parent=?")
						   ->set(array('column_parent'=>$objElements->id,'column_name'=>$strName))
						   ->execute($intId,$objElements->column_parent);

			$objParts = $this->Database->prepare("SELECT * FROM tl_form_field WHERE column_parent=? AND type!=? ORDER BY column_sortid")->execute($objElements->id,'formColsStart');

			$arrChilds= array();

			while($objParts->next())
			{

				$strName = $objParts->type == 'formColsEnd' ? 'colset.' . $objElements->id . '-End' : 'colset.' . $objElements->id . '-Part-' . $objParts->column_sortid;
				$this->Database->prepare("UPDATE tl_form_field %s WHERE id=?")
						   ->set(array('column_name'=>$strName))
						   ->execute($objParts->id);

				$arrChilds[] = $objParts->id;
			}

			$this->Database->prepare("UPDATE tl_form_field %s WHERE id=?")
						   ->set(array('column_childs'=>$arrChilds))
						   ->execute($objElements->id);

		}

	}

}
